import 'package:get/get_rx/src/rx_types/rx_types.dart';
import 'package:mypoint_flutter_app/networking/restful_api_request.dart';
import '../../base/restful_api_viewmodel.dart';
import '../../preference/data_preference.dart';
import 'model/payment_bank_account_info_model.dart';
import 'model/payment_method_model.dart';
import 'model/preview_order_payment_model.dart';

class TransactionDetailViewModel extends RestfulApiViewModel {
  var previewData = Rxn<PreviewOrderPaymentModel>();
  var paymentMethods = RxList<PaymentMethodModel>();
  var paymentBankAccounts = RxList<PaymentBankAccountInfoModel>();
  final RxBool isLoading = false.obs;

  @override
  void onInit() {
    super.onInit();
    refreshData();
  }

  Future<void> refreshData() async {
    isLoading.value = true;
    await Future.wait([
      _getPreviewOrderPayment(),
      _getPaymentMethods(),
      _getPaymentBankAccounts(),
    ]);
    isLoading.value = false;
  }

  Future<void> _getPreviewOrderPayment() async {
    String? token = DataPreference.instance.token ?? "";
    try {
      final body = {
        "product_id": 13796,
        "quantity": 1,
        "access_token": token,
        "price": 100000,
      };
      final response = await client.getPreviewOrderInfo(body);
      previewData.value = response.data;
    } catch (error) {
      print("Error fetching preview order payment: $error");
    }
  }

  Future<void> _getPaymentMethods() async {
    try {
      final response = await client.getPreviewPaymentMethods();
      paymentMethods.value = response.data ?? [];
    } catch (error) {
      print("Error fetching payment methods: $error");
    }
  }

  Future<void> _getPaymentBankAccounts() async {
    try {
      final response = await client.getPreviewOrderBankAccounts();
      paymentBankAccounts.value = response.data ?? [];
    } catch (error) {
      print("Error fetching payment bank accounts: $error");
    }
  }
}